#
# spec file for package icmake
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           icmake
Version:        10.03.00
Release:        3.4
Summary:        A program maintenance (make) utility using a C-like grammar
License:        GPL-3.0-only
Group:          Development/Tools/Building
URL:            https://gitlab.com/fbb-git/icmake
Source:         %{URL}/-/archive/%{version}/icmake-%{version}.tar.bz2
Patch1:         prevent-double-slash.patch
Patch2:         gcc-13-fix.patch
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libbobcat-light-devel-static

%description
Icmake allows the programmer to use a program language (closely
resembling the well-known C-programming language) to define the
actions involved in (complex) program maintenance. For this, icmake
offers various special operators as well as a set of support functions
that have proven to be useful in program maintenance.

%prep
%autosetup -p1

%build
export CXXFLAGS="%{optflags} -std=c++20"
echo "/* created during rpmbuild */" >  %{name}/INSTALL.im
echo "#define BINDIR      \"%{_bindir}\"" >>  %{name}/INSTALL.im
echo "#define SKELDIR     \"%{_datadir}/%{name}\"" >>  %{name}/INSTALL.im
echo "#define MANDIR      \"%{_mandir}\"" >>  %{name}/INSTALL.im
echo "#define LIBDIR      \"%{_libdir}/%{name}\"" >>  %{name}/INSTALL.im
echo "#define CONFDIR     \"%{_sysconfdir}/%{name}\"" >>  %{name}/INSTALL.im
echo "#define DOCDIR      \"%{_docdir}/%{name}\"" >>  %{name}/INSTALL.im
echo "#define DOCDOCDIR   \"%{_docdir}/%{name}\"" >>  %{name}/INSTALL.im
pushd %{name}
./icm_prepare   "/"
./icm_bootstrap ""
popd

%install
pushd %{name}
./icm_install all %{buildroot}
popd

%files
%doc %{name}/changelog
%doc %{_docdir}/%{name}/
%{_bindir}/icmake
%{_bindir}/icmbuild
%{_bindir}/icmstart
%{_mandir}/man1/icmake.1%{ext_man}
%{_mandir}/man1/icmbuild.1%{ext_man}
%{_mandir}/man1/icmstart.1%{ext_man}
%{_mandir}/man7/icmconf.7%{ext_man}
%{_mandir}/man7/icmstart.rc.7%{ext_man}
%{_mandir}/man7/icmscript.7%{ext_man}
%{_datadir}/icmake
%dir %{_libdir}/icmake
%{_libdir}/icmake/icm-comp
%{_libdir}/icmake/icm-exec
%{_libdir}/icmake/icm-pp
%{_libdir}/icmake/icm-dep
%{_libdir}/icmake/icmun
%{_libdir}/icmake/icmbuild
%{_libdir}/icmake/icmstart.bim
%dir %{_sysconfdir}/icmake
%config %{_sysconfdir}/icmake/icmstart.rc

%changelog
* Tue Feb 28 2023 Martin Liška <mliska@suse.cz>
- Add gcc-13-fix.patch in order to fix the upstream issue:
  https://gitlab.com/fbb-git/icmake/-/issues/5
* Mon Nov 21 2022 Andreas Schwab <schwab@suse.de>
- Build with %%{optflags}
* Fri Oct 28 2022 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Break the build cycle dependency with libbobcat
  * Change build requires from libbobcat-devel to libbobcat-light-devel-static
* Wed Sep 28 2022 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Adding build requries to libbobcat on specfile.
* Fri Aug 26 2022 Valentin Lefebvre <valentin.lefebvre@suse.com>
- upgrade to 10.03.00
  * On little-engine architectures icmake 10.02.00 should not be used as it
    only writes the least significant bytes of multi-byte values to its .bim
    files. This error was repaired in version 10.03.00
- upgrade to 10.02.00
  * Daniel Bungert noticed that icmake couldn't be used on big-endian
    architectures (like the s390x emulator). The bug was caused by icmake
    using little-endian number representations in its .bim files. Starting
    this version little-endian number representations are still used in the
    .bim files, but on big-endian acrchitectures numbers are converted to
    little-endian representations before writing them to the .bim files and
    converted to big-endian representations when reading numbers from .bim
    files.
  * A cosmetic flaw was fixed in the output of the icmake unassembler.
- upgrade to 10.01.00
  * Simplified -t argument handling in icmake
  * The icmake program (again) recognizes but ignores the -q option. Existing
    icmake scripts specifying -q should not be processed by icmake
    10.00.00. Icmake users are advised to remove -q options from their icmake
    scripts.
  * Calling icmake without action option results in an error.
- upgrade to 10.00.00
  * Icmake and its support programs now converted to C++
  * Added a new manpage: icmscript(7), describing the syntaxis, construction
    and predefined support functions and other characteristics of icmake
    scripts.
  * Added new options --no-process (-N), --unassemble (-u), and --verbose (-V)
    to icmake,
  * Icmake's option --summary) (-F) has been discontinued.
  * Added new options --no-version-check (-n) to icm-exec and icmun
  * Added new option -P (no pre-processing) to --compile and --force
  * The --source short option -i has been replaced by -s;
  * The predefined functions printf and fprintf also support the << insertion
    operator (comparable to C++'s std::ostream class).
  * Changed the organization of the class-dependencies matrices shown by
    'icmake -d' (icm_dep), simplifying visual inspection of circular
    class-dependencies
  * Fixed a flaw in handling precompiled headers in the std. icmbuild script
    causing precompilation of modified headers at the second icmbuild run.
- new library file icmstart.bim comming from commit ecb0d3f1
  [10.03.00.tar.bz2]
* Sat May  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fixed SourceUrl
* Fri Jan 17 2020 Josef Möllers <josef.moellers@suse.com>
- Upgrade to 9.03.01
  * updated the usr/share/icmake/icmconf file
  * Removed an error (#-lines are comment) in the icmconf(7) man-page
  * Fixed icmbuild's install command wrt installing libraries
  * Using ctrl-C while executing icmstart no longer requires a terminal
    reset when using bash as command shell (in fact: icm-exec restores
    the initial terminal (stdin) configuration when terminated by ctrl-C).
  * The standard icmake skeleton files specify namespace Icmake instead of
    the previously used namespace Icmbuild.
  * The icmbuild strip command is discontinued: use -s instead
  * Stripping (-s) can only be specified when installing
  * icmbuild options -c can only be specified when building libraries or
    programs
  * Redesigned icm-comp's implementation
  * Changed icm-exec's int comparison function: returns 1 if equal, 0 if not
  * The file 'version.cc' wasn't correctly recognized in
    /usr/lib/icmake/icmbuild: fixed in this release.
  * Fixed unintended termination of /usr/lib/icmake/icmbuild caused by
    non-existing .gch files (when PRECOMP was specified; this happened
    when a directory only contained a header, but no sources).
  [9.03.01.tar.gz]
* Tue Feb  7 2017 dimstar@opensuse.org
- Explicitly package %%{_docdir}/%%{name} to fix build with RPM 4.13.
* Thu Feb  2 2017 josef.moellers@suse.com
- Upgrade to 9.02.02
  * Fixed an annoying typo in [/usr/lib/icmake/]icmbuild.
- Upgrade to 9.02.01
  * Fixed a flaw in [/usr/lib/icmake/]icmbuild: when DEFCOM "library" was
    defined in icmconf, and precompiled headers were requested, then MAIN had
    to be defined as well. This is not required anymore.
- Upgrade to 9.02.00
  * icmbuild now is a small program, providing help or starting the icmbuild
    script in LIBDIR (cf. INSTALL)
  * Man-pages were updated
  * Cosmetic changes to icmake --help's output
  * The name of the optional configuration file YEAR was changed to YEARS
    (as it defines YEARS, not YEAR)
  * `icmconf' was added to /etc/icmake/icmstart.rc
  * As mentioned in icmake's man-page the program `icmun' is mainly used in
    some specific situations. In icmake's daily practice it isn't
    used. Therefore it was moved from the standard binary programs directory
    to icmake's LIB directory (commonly /usr/lib/icmake).
  * The file /etc/icmake/icmake.rc was nowhere used and was removed.
- Upgrade to 9.01.00
  * Man-pages weren't properly updated at 9.00.00. This was fixed in this
    release.
- Upgrade to 9.00.00
  * Added support program icm-dep computing dependencies for USE_ALL classes
    and precompiled headers, called from /usr/bin/icmbuild, or directly using
    icmake's option --icm-dep (-d)
  * Icmake supports several long options in addition to the standard short
    options. See icmake(1) for details.
  * Changed references to IS_* into O_* in icmake(1)'s man-page. The IS_
    entries were already unavailable, but the man-page still referred to
    them. Now fixed.
  * Contents of lines in CLASSES beyond the first word are no longer
    interpreted.
  * Added new option NO_PRECOMP_WARNING to icmconf
  * Option -b was removed from icmake.
  * The built-in function makelist(mask, [younger,older], referencefile) is now
    operational (was mentioned in icmake's man-page, but wasn't implemented
    before).
  * Repaired a bug in substr that could segfault.
  * Man-pages updated. Icmbuild(1) contains a description of the icm-dep
    program.
* Sun Feb 28 2016 mpluskal@suse.com
- Update to 8.01.00
  * See changelog for details
* Tue Jan 12 2016 mpluskal@suse.com
- Do not run updatescanner as it breaks build
* Sun Jan 10 2016 mpluskal@suse.com
- Update to 8.00.05
  * see attached changelog
- Drop no longer necessary adapt-examples-path.patch
- Don't strip installed binaries
- Cleanup spec file with spec-cleaner
* Fri Dec  4 2015 mpluskal@suse.com
- Revert part of previous changes
- Build with correct cflags
* Thu Dec  3 2015 p.drouand@gmail.com
- Update to version 7.23.04
  * Please read the changelog file
- Update project and download Urls
* Sun Jul 28 2013 p.drouand@gmail.com
- Update to version 7.20.00
  * added missing '\n' to the strtok call in icmbuild's 'dependenciesOf'
    function
  * line continuation in CLASSES results in one line being counted in the
    icmbuild script.
  * Added suggestions by Johann 'Myrkraverk' Oskarsson about compiling icmake
    on solaris (in ./contributions/solaris)
* Thu Jan  3 2013 kkaempf@suse.com
- Clarified license with author: GPL-3.0 (bnc#795979)
* Wed Dec 12 2012 kkaempf@suse.com
- Fix doc path for RedHat/CentOS
* Wed Dec 12 2012 kkaempf@suse.com
- Initial version 7.19.00
